@@ -108,21 +108,23 @@ gzip_output_header (GsfOutputGZip *gzip)
 /**
  * gsf_output_gzip_new :
  * @sink : The underlying data source.
- * @err	   : optionally NULL.
+ * @err	   : optionally %NULL.
  *
  * Adds a reference to @sink.
  *
- * Returns a new file or NULL.
+ * Returns: a new file or %NULL.
  **/
 GsfOutput *
 gsf_output_gzip_new (GsfOutput *sink, GError **err)
 {
 	GsfOutput *output;
-	const GError *con_err;
+	GError const *con_err;
 
 	g_return_val_if_fail (GSF_IS_OUTPUT (sink), NULL);
 
 	output = g_object_new (GSF_OUTPUT_GZIP_TYPE, "sink", sink, NULL);
+	if (G_UNLIKELY (NULL == output)) return NULL;
+
 	con_err = gsf_output_error (output);
 
 	if (con_err) {
@@ -397,6 +399,6 @@ gsf_output_gzip_class_init (GObjectClass *gobject_class)
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_DYNAMIC_CLASS (GsfOutputGZip, gsf_output_gzip,
-		   gsf_output_gzip_class_init, gsf_output_gzip_init,
-		   GSF_OUTPUT_TYPE)
+GSF_CLASS (GsfOutputGZip, gsf_output_gzip,
+	   gsf_output_gzip_class_init, gsf_output_gzip_init,
+	   GSF_OUTPUT_TYPE)
